summaryrefslogtreecommitdiff
path: root/svx/source/engine3d/helperminimaldepth3d.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'svx/source/engine3d/helperminimaldepth3d.cxx')
-rw-r--r--svx/source/engine3d/helperminimaldepth3d.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/svx/source/engine3d/helperminimaldepth3d.cxx b/svx/source/engine3d/helperminimaldepth3d.cxx
index 85ba97f1a826..35ebb4dec0f6 100644
--- a/svx/source/engine3d/helperminimaldepth3d.cxx
+++ b/svx/source/engine3d/helperminimaldepth3d.cxx
@@ -70,8 +70,8 @@ namespace drawinglayer
void MinimalDephInViewExtractor::processBasePrimitive3D(const primitive3d::BasePrimitive3D& rCandidate)
{
- // it is a BasePrimitive3D implementation, use getPrimitiveID() call for switch
- switch(rCandidate.getPrimitiveID())
+ // it is a BasePrimitive3D implementation, use getPrimitive3DID() call for switch
+ switch(rCandidate.getPrimitive3DID())
{
case PRIMITIVE3D_ID_TRANSFORMPRIMITIVE3D :
{